@@ -1,8 +1,4 @@
-package Bundle::CGI::Builder::Complete;
-$VERSION = 1.26;
-
-# If you have any problem with the coding style used here
-# you should read http://perl.4pro.net/perlish_coding_style.html
+; package Bundle::CGI::Builder::Complete
 
 __END__
 
